var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { h } from "@stencil/core";
import { DataTestIdsEnum } from "../../../../../constants/dataTestIds.enum";
import { formatAddress } from "../../../../../utils/utils";
import state from "../../signTransactionsPanelStore";
export class SignTransaction {
    constructor() {
        this.isConfirming = false;
        this.previousIndex = -1;
    }
    componentWillRender() {
        const { currentIndex } = state.commonData;
        if (this.previousIndex !== -1 && currentIndex !== this.previousIndex) {
            this.isConfirming = false;
        }
        this.previousIndex = currentIndex;
    }
    onConfirm() {
        this.isConfirming = true;
        state.onConfirm();
    }
    getSignButtonProps() {
        const { needsSigning, providerName } = state.commonData;
        const confirmText = providerName ? `Confirm on ${providerName}` : 'Confirm';
        if (needsSigning) {
            return {
                'signText': this.isConfirming ? confirmText : 'Sign',
                'disabled': state.isWaitingForSignature || this.isConfirming,
                'data-testid': DataTestIdsEnum.signTransactionBtn,
                'onClick': this.onConfirm.bind(this),
            };
        }
        return {
            'signText': 'Next',
            'disabled': false,
            'data-testid': DataTestIdsEnum.signNextTransactionBtn,
            'onClick': this.onConfirm.bind(this),
        };
    }
    getBackButtonProps() {
        const { transactionsCount, currentIndex } = state.commonData;
        const isMultipleTransactions = transactionsCount > 1;
        if (!isMultipleTransactions) {
            return {};
        }
        if (currentIndex === 0) {
            return {
                'data-testid': DataTestIdsEnum.signCancelBtn,
                'backButtonText': 'Cancel',
                'onClick': state.onCancel,
            };
        }
        return {
            'data-testid': DataTestIdsEnum.signBackBtn,
            'backButtonText': 'Back',
            'onClick': state.onBack,
            'disabled': state.isWaitingForSignature || this.isConfirming,
        };
    }
    getHighlightedData() {
        const { data, highlight } = state.commonData;
        if (!highlight || !data) {
            return data;
        }
        const parts = data.split(highlight);
        return (h("span", null, parts.map((part, index) => (h("span", null, h("span", { class: "data-content" }, part), index < parts.length - 1 && h("span", { class: "highlight" }, highlight))))));
    }
    render() {
        const { receiver, scCall } = state.commonData;
        const _a = this.getSignButtonProps(), { signText } = _a, signButtonProps = __rest(_a, ["signText"]);
        const _b = this.getBackButtonProps(), { backButtonText } = _b, backButtonProps = __rest(_b, ["backButtonText"]);
        const highlightedData = this.getHighlightedData();
        return (h("div", { key: '88594b8669f39b650f8ec8da2099af3da5e1b791', class: "transaction-container" }, this.header, h("div", { key: '25edfcbb7309edf3c6385e77e50bf27df211ce33', class: "receiver-container" }, h("p", { key: 'c3adec2b0ae4a2ed8d6e5e16a52fc42adb095a22' }, "To"), h("p", { key: '8977e54ee336ff3bc8b60d1b2b2366d7714ffaed' }, formatAddress(receiver, 40))), h("mvx-transaction-fee-component", { key: '1f218b5d84ea80d996bb0e79e7e2eb28e4b64694' }), scCall && (h("div", { key: 'e04fb651af6b8ab80a729eca5c5488dc1149a82d', class: "data-container" }, h("p", { key: '8f492993338b97e4644384531733e910acfaf634' }, "Smart Contract Call"), h("div", { key: '542dedcc360995f38520189a285c5cd241946675', class: "data-content-container" }, scCall))), h("div", { key: '1c7a2b7e6fb42f571bc121e99d063c4b0a316272', class: "data-container" }, h("p", { key: '13d94093de90119fd538a109fa3718480e1d566c' }, "Data"), h("div", { key: '2caa6d7b5b72d7a5b6e4922af3749195e27a5b05', class: "data-content-container" }, highlightedData)), h("div", { key: 'a1008eee38c3b0e03c3ca406f88f960d0444938a', class: "sign-button-container" }, h("button", Object.assign({ key: '3e7f18f376af2f25f0b9edc3d1c4ffe7cf774f0f', class: "sign-button" }, signButtonProps), signText), backButtonText && (h("button", Object.assign({ key: 'e76a95d5ddecf489a5956211f7ce550578e18844', class: "sign-back-button" }, backButtonProps), backButtonText)))));
    }
    static get is() { return "mvx-sign-transaction-component"; }
    static get originalStyleUrls() {
        return {
            "$": ["sign-transaction-component.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["sign-transaction-component.css"]
        };
    }
    static get properties() {
        return {
            "header": {
                "type": "unknown",
                "attribute": "header",
                "mutable": false,
                "complexType": {
                    "original": "VNode",
                    "resolved": "VNode",
                    "references": {
                        "VNode": {
                            "location": "import",
                            "path": "@stencil/core",
                            "id": "node_modules::VNode"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
    static get states() {
        return {
            "isConfirming": {}
        };
    }
}
//# sourceMappingURL=sign-transaction-component.js.map
